@@ -9,25 +9,35 @@ PYPROJECT = ROOT / "pyproject.toml"
 DOCS = ROOT / "docs"
 REFERENCING = ROOT / "referencing"
 
+REQUIREMENTS = dict(
+    docs=DOCS / "requirements.txt",
+    tests=ROOT / "test-requirements.txt",
+)
+REQUIREMENTS_IN = [  # this is actually ordered, as files depend on each other
+    path.parent / f"{path.stem}.in" for path in REQUIREMENTS.values()
+]
+
+SUPPORTED = ["3.8", "3.9", "3.10", "3.11", "3.12", "pypy3.10"]
+LATEST = "3.12"
 
 nox.options.sessions = []
 
 
-def session(default=True, **kwargs):  # noqa: D103
+def session(default=True, python=LATEST, **kwargs):  # noqa: D103
     def _session(fn):
         if default:
             nox.options.sessions.append(kwargs.get("name", fn.__name__))
-        return nox.session(**kwargs)(fn)
+        return nox.session(python=python, **kwargs)(fn)
 
     return _session
 
 
-@session(python=["3.8", "3.9", "3.10", "3.11", "3.12", "pypy3"])
+@session(python=SUPPORTED)
 def tests(session):
     """
     Run the test suite with a corresponding Python version.
     """
-    session.install("-r", ROOT / "test-requirements.txt")
+    session.install("-r", REQUIREMENTS["tests"])
 
     if session.posargs and session.posargs[0] == "coverage":
         if len(session.posargs) > 1 and session.posargs[1] == "github":
@@ -109,7 +119,7 @@ def docs(session, builder):
     """
     Build the documentation using a specific Sphinx builder.
     """
-    session.install("-r", DOCS / "requirements.txt")
+    session.install("-r", REQUIREMENTS["docs"])
     with TemporaryDirectory() as tmpdir_str:
         tmpdir = Path(tmpdir_str)
         argv = ["-n", "-T", "-W"]
@@ -147,7 +157,7 @@ def requirements(session):
     Update the project's pinned requirements. Commit the result.
     """
     session.install("pip-tools")
-    for each in [DOCS / "requirements.in", ROOT / "test-requirements.in"]:
+    for each in REQUIREMENTS_IN:
         session.run(
             "pip-compile",
             "--resolver",
